@@ -9,7 +9,7 @@ use POSIX qw/sys_wait_h/;
 use JSON;
 use Slack::RTM::Bot::Client;
 
-our $VERSION = "1.03";
+our $VERSION = "1.04";
 
 pipe(READH, WRITEH);
 select(WRITEH);$|=1;
@@ -170,7 +170,7 @@ sub say {
 		subtype => 'bot_message',
 		bot_id  => $self->{client}->{info}->{self}->{id},
 		%$args,
-		channel => $self->{client}->{info}->_find_channel_or_group_id($args->{channel})
+		channel => $self->{client}->find_channel_or_group_id($args->{channel})
 	})."\n";
 	print WRITEH $request;
 }
